@@ -1,4 +1,4 @@
-# Copyright (C) 2009 by the Free Software Foundation, Inc.
+# Copyright (C) 2009, 2010 by Barry A. Warsaw
 #
 # This file is part of flufl.i18n
 #
@@ -25,13 +25,14 @@ __all__ = [
     ]
 
 
+import os
 import atexit
 import doctest
-import os
+import unittest
+
 # pylint: disable-msg=F0401
 from pkg_resources import (
     resource_filename, resource_exists, resource_listdir, cleanup_resources)
-import unittest
 
 
 DOCTEST_FLAGS = (
@@ -45,6 +46,10 @@ def setup(testobj):
     # Make sure future statements in our doctests match the Python code.
     testobj.globs['absolute_import'] = absolute_import
     testobj.globs['unicode_literals'] = unicode_literals
+    # Ensure that environment variables affecting translation are neutralized.
+    for envar in ('LANGUAGE', 'LC_ALL', 'LC_MESSAGES', 'LANG'):
+        if envar in os.environ:
+            del os.environ[envar]
 
 
 def additional_tests():
