@@ -21,7 +21,7 @@ does not play well with the way doctest executes Python code.  But see
 translator.txt for a description of how this should work in real Python code.
 """
 
-# pylint: disable-msg=E0611,W0142
+# pylint: disable-msg=E0611,W0142,C0103
 from __future__ import absolute_import, unicode_literals
 
 __metaclass__ = type
@@ -42,18 +42,24 @@ green = 'gerbil'
 
 
 class Catalog:
+    """Test catalog."""
+
     def __init__(self):
         self.translation = None
 
+    # pylint: disable-msg=W0613,R0201
     def ugettext(self, original):
+        """Return the translation."""
         return self.translation
 
     def charset(self):
+        """Return the encoding."""
         # The default is ascii.
         return None
 
 
 
+# pylint: disable-msg=C0111
 class TranslatorTests(unittest.TestCase):
     """Tests of the Translator class."""
 
@@ -65,6 +71,7 @@ class TranslatorTests(unittest.TestCase):
 
     def test_locals(self):
         # Test that locals get properly substituted.
+        # pylint: disable-msg=W0612
         aqua = 'aardvarks'
         blue = 'badgers'
         cyan = 'cats'
@@ -80,6 +87,7 @@ class TranslatorTests(unittest.TestCase):
 
     def test_dict_overrides_locals(self):
         # Test that explicit mappings override locals.
+        # pylint: disable-msg=W0612
         aqua = 'aardvarks'
         blue = 'badgers'
         cyan = 'cats'
@@ -88,8 +96,8 @@ class TranslatorTests(unittest.TestCase):
         self.assertEqual(self.translator.translate('source string', overrides),
                          'bats and cats and aardvarks')
 
-    def test_globals(self):
-        # Test that globals get properly substituted.
+    def test_globals_with_overrides(self):
+        # Test that globals with overrides get properly substituted.
         self.catalog.translation = '$purple and $magenta and $green'
         overrides = dict(green='giraffe')
         self.assertEqual(self.translator.translate('source string', overrides),
@@ -101,6 +109,7 @@ class TranslatorTests(unittest.TestCase):
 
     def test_dedent(self):
         # By default, the translated string is always dedented.
+        # pylint: disable-msg=W0612
         aqua = 'aardvarks'
         blue = 'badgers'
         cyan = 'cats'
@@ -114,6 +123,7 @@ class TranslatorTests(unittest.TestCase):
 
     def test_no_dedent(self):
         # You can optionally suppress the dedent.
+        # pylint: disable-msg=W0612
         aqua = 'aardvarks'
         blue = 'badgers'
         cyan = 'cats'
